# Sun Data

<div align="center">

![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/night-works/sundata/python-app.yml?style=for-the-badge)
![Codecov branch](https://img.shields.io/codecov/c/gh/night-works/sundata/main?style=for-the-badge)
![Sonar Quality Gate](https://img.shields.io/sonar/quality_gate/night-works_sundata?server=https%3A%2F%2Fsonarcloud.io&style=for-the-badge)
![GitHub](https://img.shields.io/github/license/night-works/sundata?color=gre&style=for-the-badge)

</div>
